@@ -1,13 +1,13 @@
 import functools
+import inspect
 from collections.abc import Callable, Iterable
 from typing import Any, overload
 
 import attrs
-import wrapt
 
 from liblaf import grapes
 
-from .typed import PluginId
+from .typing import MethodName, PluginId
 
 
 @attrs.define
@@ -43,18 +43,31 @@ def impl(
     if func is None:
         return functools.partial(impl, priority=priority, after=after, before=before)
 
-    @wrapt.decorator
+    info = ImplInfo(after=after, before=before, priority=priority)
+
+    @grapes.decorator
     def wrapper(
         wrapped: Callable, _instance: Any, args: tuple, kwargs: dict[str, Any]
     ) -> Any:
         return wrapped(*args, **kwargs)
 
-    proxy: Any = wrapper(func)  # pyright: ignore[reportCallIssue]
-    proxy._self_impl = ImplInfo(after=after, before=before, priority=priority)  # noqa: SLF001
-    return proxy
+    func = wrapper(func)
+    grapes.wrapt_setattr(func, "impl", info)
+    return func
+
+
+def collect_impls(cls: Any) -> dict[MethodName, ImplInfo]:
+    if isinstance(cls, type):
+        cls = type(cls)
+    return {
+        name: grapes.wrapt_getattr(method, "impl")
+        for name, method in inspect.getmembers(
+            cls, lambda m: grapes.wrapt_getattr(m, "impl", None) is not None
+        )
+    }
 
 
 def get_impl_info(func: Callable | None) -> ImplInfo | None:
     if func is None:
         return None
-    return grapes.unbind_getattr(func, "_self_impl", None)
+    return grapes.wrapt_getattr(func, "impl", None)
