@@ -1,18 +1,17 @@
 import contextlib
 import datetime
-import functools
 from collections.abc import Mapping
 from pathlib import Path
 from typing import Any
 
 import attrs
-import git
 
-from liblaf.cherries import paths
-from liblaf.cherries.typed import PathLike
+from liblaf.cherries import path_utils
+from liblaf.cherries.typing import PathLike
 
 from ._plugin import Plugin
 from ._spec import spec
+from ._utils import plugin_cached_property, plugin_property
 
 
 @attrs.define
@@ -25,69 +24,41 @@ class Run(Plugin):
         3. [MLflow Tracking APIs | MLflow](https://www.mlflow.org/docs/latest/ml/tracking/tracking-api/)
     """
 
-    @functools.cached_property
+    @plugin_cached_property
     def data_dir(self) -> Path:
-        if self._plugin_parent is not None:
-            return self.plugin_root.data_dir
-        return paths.data()
+        return path_utils.data()
 
-    @functools.cached_property
+    @plugin_cached_property
     def entrypoint(self) -> Path:
-        if self._plugin_parent is not None:
-            return self.plugin_root.entrypoint
-        return paths.entrypoint()
+        return path_utils.entrypoint()
 
-    @functools.cached_property
+    @plugin_cached_property
     def exp_dir(self) -> Path:
-        if self._plugin_parent is not None:
-            return self.plugin_root.exp_dir
-        return paths.exp_dir()
+        return path_utils.exp_dir()
 
-    @functools.cached_property
+    @plugin_cached_property
     def name(self) -> str:
-        if self._plugin_parent is not None:
-            return self.plugin_root.name
         return self.start_time.strftime("%Y-%m-%dT%H%M%S")
 
-    @property
+    @plugin_property
     def params(self) -> Mapping[str, Any]:
-        if self._plugin_parent is not None:
-            return self.plugin_root.params
-        return self.get_params()
+        return self.plugin_root.get_params()
 
-    @functools.cached_property
+    @plugin_cached_property
     def project_name(self) -> str | None:
-        if self._plugin_parent is not None:
-            return self.plugin_root.project_name
-        try:
-            repo: git.Repo = git.Repo(search_parent_directories=True)
-        except git.InvalidGitRepositoryError:
-            return None
-        else:
-            return Path(repo.working_dir).name
+        return self.project_dir.name
 
-    @functools.cached_property
-    def root_dir(self) -> Path:
-        if self._plugin_parent is not None:
-            return self.plugin_root.root_dir
-        try:
-            repo: git.Repo = git.Repo(search_parent_directories=True)
-        except git.InvalidGitRepositoryError:
-            return self.entrypoint.parent
-        else:
-            return Path(repo.working_dir).absolute()
+    @plugin_cached_property
+    def project_dir(self) -> Path:
+        return path_utils.project_dir()
 
-    @functools.cached_property
+    @plugin_cached_property
     def start_time(self) -> datetime.datetime:
-        if self._plugin_parent is not None:
-            return self.plugin_root.start_time
         return datetime.datetime.now().astimezone()
 
-    @functools.cached_property
+    @plugin_property
     def url(self) -> str:
-        if self._plugin_parent is not None:
-            return self.plugin_root.url
-        return self.get_url()
+        return self.plugin_root.get_url()
 
     @spec
     def end(self, *args, **kwargs) -> None: ...
@@ -181,7 +152,6 @@ class Run(Plugin):
 
     @spec(delegate=False)
     def start(self, *args, **kwargs) -> None:
-        self._plugins_prepare()
         self.delegate("start", args, kwargs)
 
 
